/*
 * Items: asinh(
 * Standardized-By: SuS
 * Not-Detected-by: gcc-4.4.3 + Linux
 */

#include <math.h>

int main(int arg, char **argv)
{
    asinh(-23.0);
}
